/* synthetic */ module us.fatehi.schemacrawler.schemacrawler {
    requires java.sql;
    requires java.logging;

    exports us.fatehi.utility;
    exports us.fatehi.utility.database;
    exports us.fatehi.utility.datasource;
    exports us.fatehi.utility.graph;
    exports us.fatehi.utility.html;
    exports us.fatehi.utility.ioresource;
    exports us.fatehi.utility.property;
    exports us.fatehi.utility.readconfig;
    exports us.fatehi.utility.scheduler;
    exports us.fatehi.utility.string;
    exports schemacrawler.schema;
    exports schemacrawler.schemacrawler;
    exports schemacrawler.schemacrawler.exceptions;
    exports schemacrawler.filter;
    exports schemacrawler.inclusionrule;
    exports schemacrawler.plugin;
    exports schemacrawler.utility;
    exports schemacrawler.tools.catalogloader;
    exports schemacrawler.tools.databaseconnector;
    exports schemacrawler.tools.executable;
    exports schemacrawler.tools.executable.commandline;
    exports schemacrawler.tools.options;
    exports schemacrawler.tools.registry;
    exports schemacrawler.tools.utility;
    exports schemacrawler.ermodel.model;
    exports schemacrawler.ermodel.utility;
    exports schemacrawler.loader.utility;

    opens schemacrawler.schema to tools.jackson.databind;

    provides CatalogLoader with AttributesCatalogLoader, TableRowCountsCatalogLoader, WeakAssociationsCatalogLoader, SchemaCrawlerCatalogLoader;

}

